<?php

/**
 * Content width
 */

if ( ! isset( $content_width ) )
	$content_width = 1200;

/**
 * Theme setup
 */

add_action( 'after_setup_theme', 'tz_theme_setup' );
function tz_theme_setup() {
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Title tag
	add_theme_support( 'title-tag' );

	// Register WP 3.0+ Menus
	register_nav_menus( array( 'left-menu' => __( 'Left Menu', 'schools' ), 'right-menu' => __( 'Right Menu', 'schools' ) ) );

	// Post thumbnail support
	add_theme_support( 'post-thumbnails' );

	// Add custom post thumbnail sizes
	add_image_size( 'tz_home_slide', 1440, 600, true );
	add_image_size( 'tz_gallery_widget', 80, 80, true );
}

/**
 * Adding custom image sizes to media uploader
 */

add_filter( 'image_size_names_choose', 'tz_image_sizes' );
function tz_image_sizes( $sizes ) {
	$add_sizes = array(
		"tz_home_slide" => __( 'Home slide', 'schools' )
	);
	$new_sizes = array_merge( $sizes, $add_sizes );

	return $new_sizes;
}

/**
 * Get image
 */

function tz_get_image( $post_id, $size, $id = false ) {
	$post = get_children(
		array(
			'post_parent' => $post_id,
			'post_type'   => 'attachment',
			'numberposts' => 1
		)
	);

	if ( $post ) {
		foreach( $post as $p ) {
			$attachment_id = $p->ID;
			$attachment = wp_get_attachment_image_src( $attachment_id, $size );
		}

		if ( isset( $attachment ) && $attachment ) {
			if ( $id )
				return $attachment_id;

			return $attachment[0];
		}
	}
}

/**
 * Load styles
 */

add_action( 'wp_enqueue_scripts', 'tz_enqueue_styles' );
function tz_enqueue_styles() {
  wp_enqueue_style( 'tz-style', get_stylesheet_uri() );
}

/**
 * Load scripts
 */

add_action( 'wp_enqueue_scripts', 'tz_enqueue_scripts' );
function tz_enqueue_scripts() {
	wp_register_script( 'jquery-min', get_template_directory_uri() . '/assets/scripts/jquery-1.11.1.min.js', 'jquery', '1.11.1', TRUE );
	wp_register_script( 'plugins', get_template_directory_uri() . '/assets/scripts/plugins.js', 'jquery', '0.0.1', TRUE );
	wp_register_script( 'main', get_template_directory_uri() . '/assets/scripts/main.js', 'jquery', '0.0.1', TRUE );

	wp_enqueue_script( 'jquery-min' );
	wp_enqueue_script( 'plugins' );
	wp_enqueue_script( 'main' );

	if ( is_single() )
		wp_enqueue_script( 'comment-reply' );

	wp_localize_script( 'main', 'tz', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
}

/**
 * Filter search results
 */

add_filter( 'pre_get_posts', 'tz_search_filter' );
function tz_search_filter( $query ) {
	if ( $query->is_search )
		$query->set( 'post_type', 'post' );

	return $query;
}

/**
 * Pagination
 */

function tz_pagination( $range = 2 ) {
	global $wp_query, $paged;

	$showitems = ( $range * 2 ) + 1;
	$paged = ( empty( $paged ) ) ? 1 : $paged;
	$pages = ( ! $wp_query->max_num_pages ) ? 1 : $wp_query->max_num_pages;

    if ( $pages != 1 ) {
		echo '<nav class="pagination clearfix">';

		if ( $paged > 1 ) {
			echo '<a class="previous" href="' . get_pagenum_link( $paged - 1 ) . '">' . __( '&larr; Previous', 'schools' ) . '</a>';
		}

		for ( $i = 1; $i <= $pages; $i++ ) {
			if ( $pages != 1 && ( ! ( $i >= $paged + $range + 1 || $i <= $paged - $range - 1 ) || $pages <= $showitems ) ) {
				echo ( $paged == $i ) ? '<span class="current">' . $i . '</span>' : '<a href="' . get_pagenum_link( $i ) . '">' . $i . '</a>';
			}
		}

		if ( $paged < $pages ) {
			echo '<a class="next" href="' . get_pagenum_link( $paged + 1 ) . '">' . __( 'Next &rarr;', 'schools' ) . '</a>';
		}

        echo '</nav>' . "\n";
     }
}

/**
 * Contact Form
 */

add_action( 'wp_ajax_nopriv_tz_contact_form', 'tz_ajax_contact_form' );
add_action( 'wp_ajax_tz_contact_form', 'tz_ajax_contact_form' );
function tz_ajax_contact_form() {
	$params = array();

	parse_str( $_POST['data'], $params );

	$name = trim( $params['name'] );
	$email = $params['email'];
	$message = $params['message'];
	$subject = $params['subject'];
	$website = $params['website'];
	$admin_email = ( get_theme_mod( 'tz_contact_email' ) ) ? get_theme_mod( 'tz_contact_email' ) : get_option( 'admin_email' );

	if ( $subject == "" )
		$subject = __( 'A message from contact form at ', 'schools' ) . get_bloginfo( 'name' );

	if ( $name == "" )
		$error['name'] = '<div class="message error">' . __( 'Please enter your name', 'schools' ) . '</div>';

	if ( ! is_email( trim( $email ) ) )
		$error['email'] = '<div class="message error">' . __( 'Your email is invalid', 'schools' ) . '</div>';

	if ( $message == "" )
		$error['message'] = '<div class="message error">' . __( 'Please enter your message', 'schools' ) . '</div>';

	if ( ! isset( $error ) ) {
		$body = 'Name: ' . $name . "\n\n";
		$body.= 'Email: ' . $email . "\n\n";
		$body.= 'Website: ' . $website . "\n\n";
		$body.= 'Message: ' . $message;
		$headers = 'From: ' . $name . ' <' . $email . '>' . "\r\n";
		$headers.= 'Reply-To: ' . $email;
		wp_mail( $admin_email, $subject, $body, $headers );
		$success['success'] = '<div class="message success">' . __( 'Thank you! Your message will be replied soon.', 'schools' ) . '</div>';
		echo json_encode( $success );
	} else {
		echo json_encode( $error );
	}

	exit();
}

/**
 * Custom body class
 */

add_filter( 'body_class', 'custom_body_class' );
function custom_body_class( $classes ) {
	if ( is_home() || is_front_page() ) {
		$classes[] = 'homepage';
	}

	return $classes;
}

/**
 * Register widgets
 */

add_action( 'widgets_init', 'tz_widgets_init' );
function tz_widgets_init() {
 	register_sidebar(
	 	array(
	 		'name' => __( 'Main Sidebar', 'schools' ),
	 		'description' => __( 'Widget area for blog pages.', 'schools' ),
	 		'id' => 'sidebar-main',
	 		'before_widget' => '<div id="%1$s" class="widget %2$s">',
	 		'after_widget' => '</div>',
	 		'before_title' => '<h2 class="widget-title">',
	 		'after_title' => '</h2>',
	 	)
 	);

 	register_sidebars( 4,
	 	array (
	 		'name' => __( 'Footer Column %d', 'schools' ),
	 		'id' => 'footer-column',
	 		'before_widget' => '<article id="%1$s" class="widget col-2 %2$s">',
	 		'after_widget' => '</article>',
	 		'before_title' => '<h3 class="widget-title">',
	 		'after_title' => '</h3>'
	 	)
	);
}

/**
 * Custom post numbers
 */

add_action( 'pre_get_posts', 'set_posts_per_page_cpt' );
function set_posts_per_page_cpt( $query ) {
	if ( ! is_admin() && $query->is_main_query() && is_post_type_archive( 'tz_gallery' ) ) {
  	$query->set( 'posts_per_page', '48' );
 	} elseif ( ! is_admin() && $query->is_main_query() && is_post_type_archive( 'tz_teacher' ) ) {
  	$query->set( 'posts_per_page', '48' );
 	} elseif ( ! is_admin() && $query->is_main_query() && is_post_type_archive( 'tz_event' ) ) {
  	$query->set( 'post_status', 'future' );
		$query->set( 'posts_per_page', '5' );
		$query->set( 'order', 'ASC' );
 	}
}

/**
 * For fancy contact
 */

add_filter( 'wp_nav_menu', 'add_menuclass' );
function add_menuclass( $ulclass ) {
	return preg_replace('/<a href="#fancy"/', '<a href="#fancy" class="get-contact"', $ulclass, 1 );
}

/**
 * Calendar
 */

function tz_event_calendar( $month, $year ) {
	$prev_month = date( "m", strtotime( date( 'F', mktime( 0, 0, 0, $month, 10 ) ) . " last month" ) );
	$next_month = date( "m", strtotime( date( 'F', mktime( 0, 0, 0, $month, 10 ) ) . " next month" ) );
	$calendar = '<div class="widget calendar"><div class="head">';
	$calendar.= '<a class="prev" href="' . home_url() . '/events/?em=' . $prev_month . '"></a>';
	$calendar.= '<a class="next" href="' . home_url() . '/events/?em=' . $next_month . '"></a>';
	$calendar.= '<h4>' . date( 'F', mktime( 0, 0, 0, $month, 10 ) ) . ' ' . $year . '</h4></div>';
	$calendar.= '<div class="table">';
	$calendar.= '<table>';

	$headings = array( 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat' );

	$calendar.= '<tr>';
	foreach( $headings as $k => $h ) {
		$calendar.= '<th class="col-' . ( $k + 1 ) . '">' . $h . '</th>';
	}
	$calendar.= '</tr>';

	$running_day = date( 'w', mktime( 0, 0, 0, $month, 1, $year ) );
	$days_in_month = date( 't', mktime( 0, 0, 0, $month, 1, $year ) );
	$days_in_this_week = 1;
	$day_counter = 0;
	$dates_array = array();

	$calendar.= '<tr>';

	$old_days = range( 1, cal_days_in_month( CAL_GREGORIAN, date( "m", strtotime( date( 'F', mktime( 0, 0, 0, $month, 10 ) ) . " last month" ) ), date( 'Y' ) ) );
	$old_days = array_slice( $old_days, -$running_day, $running_day );

	for ( $x = 0; $x < $running_day; $x++ ) {
		$calendar.= '<td class="col-' . $days_in_this_week . ' disable"><div>' . $old_days[$x] . '</div></td>';
		$days_in_this_week++;
	}

	for ( $list_day = 1; $list_day <= $days_in_month; $list_day++ ) {
		$q = new WP_Query( array( 'post_type' => 'tz_event', 'post_status' => array( 'publish', 'future' ), 'day' => $list_day, 'monthnum' => $month, 'year' => $year, 'showposts' => 1 ) );
		if ( $q->have_posts() ) {
			while( $q->have_posts() ) {
				$q->the_post();
				$id[$list_day] = get_the_ID();
				$time[$list_day] = get_the_time( 'H:i A' );
				$location[$list_day] = get_post_meta( get_the_ID(), '_tz_event_location', true );
				$title[$list_day] = get_the_title();
				$summary[$list_day] = get_post_meta( get_the_ID(), '_tz_event_summary', true );
				$archival[$list_day] = ( strtotime( get_the_time( 'F d Y' ) ) <= time() ) ? true : false;
			}
		}

		$class = ( isset( $title[$list_day] ) ) ? ' upcoming' : '';
		$class = ( isset( $title[$list_day] ) && $archival[$list_day] ) ? ' archival' : $class;
		$calendar.= '<td class="col-' . $list_day . $class . '">';
		$calendar.= '<div>';
		if ( isset( $title[$list_day] ) && ! $archival[$list_day] ) {
			$calendar.= '<div class="tooltip"><div class="holder">
				<h4>' . $title[$list_day] . '</h4>
				<p class="info-line"><span class="time">' . $time[$list_day] . '</span><span class="place">' . $location[$list_day] . '</span></p>
				<p>' . $summary[$list_day] . '</p>
			</div></div>';
		}
		$calendar.= $list_day . '</div>';
		$calendar.= '</td>';

		if ( $running_day == 6 ) {
			$calendar.= '</tr>';

			if ( ( $day_counter + 1 ) != $days_in_month )
				$calendar.= '<tr>';

			$running_day = -1;
			$days_in_this_week = 0;
		}

		$days_in_this_week++; $running_day++; $day_counter++;
	}

	if ( $days_in_this_week < 8 ) {
		for ( $x = 1; $x <= ( 8 - $days_in_this_week ); $x++ ) {
			$calendar.= '<td class="col-' . $x . ' disable"><div>' . $x . '</div></td>';
		}
	}

	$calendar.= '</tr>';
	$calendar.= '</table>';
	$calendar.= '</div></div>';

	return $calendar;
}

/**
 * Comment nav
 */

function tz_comment_nav() {
 if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) {
?>
 <nav class="navigation comment-navigation" role="navigation">
	 <h2 class="screen-reader-text"><?php _e( 'Comment navigation', 'schools' ); ?></h2>
	 <div class="nav-links">
		 <?php
			 if ( $prev_link = get_previous_comments_link( __( 'Older Comments', 'schools' ) ) ) :
				 printf( '<div class="nav-previous">%s</div>', $prev_link );
			 endif;

			 if ( $next_link = get_next_comments_link( __( 'Newer Comments', 'schools' ) ) ) :
				 printf( '<div class="nav-next">%s</div>', $next_link );
			 endif;
		 ?>
	 </div><!-- .nav-links -->
 </nav><!-- .comment-navigation -->
<?php
 }
}

/**
 * Include some files
 */

require( 'functions/customizer.php' );
require( 'functions/customizer-textarea.php' );
require( 'functions/customizer-pages.php' );
require( 'functions/metaboxes.php' );
require( 'includes/meta/slide.php' );
require( 'includes/meta/feature.php' );
require( 'includes/meta/event.php' );
require( 'includes/widgets/widget-contact.php' );
require( 'includes/widgets/widget-social.php' );
require( 'includes/widgets/widget-newsletter.php' );
require( 'includes/widgets/widget-gallery.php' );
